aboutsummaryrefslogtreecommitdiffstats
path: root/src/net
diff options
context:
space:
mode:
authorEmil Ivov <emcho@jitsi.org>2013-02-27 07:54:33 +0000
committerEmil Ivov <emcho@jitsi.org>2013-02-27 07:54:33 +0000
commite6ea78923d6c6fa7f93191df1e6aced1b9b41700 (patch)
treeb2fe2b904fc172be2a5ae55c60fac18b1e87f0bd /src/net
parent528bdb40d576c01e433242bed5ecc48849fc8624 (diff)
downloadjitsi-e6ea78923d6c6fa7f93191df1e6aced1b9b41700.zip
jitsi-e6ea78923d6c6fa7f93191df1e6aced1b9b41700.tar.gz
jitsi-e6ea78923d6c6fa7f93191df1e6aced1b9b41700.tar.bz2
renames the CoBri extension to COLIBRI (for COnferencing with LIghtwight BRIdging)
Diffstat (limited to 'src/net')
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/CallJabberImpl.java288
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/CallPeerJabberImpl.java10
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/CallPeerMediaHandlerJabberImpl.java34
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/OperationSetVideoBridgeImpl.java32
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/ProtocolProviderServiceJabberImpl.java14
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/RawUdpTransportManager.java144
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/extensions/colibri/ColibriConferenceIQ.java (renamed from src/net/java/sip/communicator/impl/protocol/jabber/extensions/cobri/CobriConferenceIQ.java)28
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/extensions/colibri/ColibriIQProvider.java (renamed from src/net/java/sip/communicator/impl/protocol/jabber/extensions/cobri/CobriIQProvider.java)50
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/extensions/colibri/ColibriStreamConnector.java (renamed from src/net/java/sip/communicator/impl/protocol/jabber/extensions/cobri/CobriStreamConnector.java)8
9 files changed, 306 insertions, 302 deletions
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/CallJabberImpl.java b/src/net/java/sip/communicator/impl/protocol/jabber/CallJabberImpl.java
index 523aeb9..4844234 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/CallJabberImpl.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/CallJabberImpl.java
@@ -9,7 +9,7 @@ package net.java.sip.communicator.impl.protocol.jabber;
import java.lang.ref.*;
import java.util.*;
-import net.java.sip.communicator.impl.protocol.jabber.extensions.cobri.*;
+import net.java.sip.communicator.impl.protocol.jabber.extensions.colibri.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.jingle.*;
import net.java.sip.communicator.impl.protocol.jabber.jinglesdp.*;
import net.java.sip.communicator.service.protocol.*;
@@ -43,19 +43,19 @@ public class CallJabberImpl
* The Jitsi VideoBridge conference which the local peer represented by this
* instance is a focus of.
*/
- private CobriConferenceIQ cobri;
+ private ColibriConferenceIQ colibri;
/**
* The shared <tt>CallPeerMediaHandler</tt> state which is to be used by the
- * <tt>CallPeer</tt>s of this <tt>Call</tt> which use {@link #cobri}.
+ * <tt>CallPeer</tt>s of this <tt>Call</tt> which use {@link #colibri}.
*/
- private MediaHandler cobriMediaHandler;
+ private MediaHandler colibriMediaHandler;
/**
- * Contains one CobriStreamConnector for each <tt>MediaType</tt>
+ * Contains one ColibriStreamConnector for each <tt>MediaType</tt>
*/
- private final List<WeakReference<CobriStreamConnector>>
- cobriStreamConnectors;
+ private final List<WeakReference<ColibriStreamConnector>>
+ colibriStreamConnectors;
/**
* Initializes a new <tt>CallJabberImpl</tt> instance belonging to
@@ -74,11 +74,11 @@ public class CallJabberImpl
int mediaTypeValueCount = MediaType.values().length;
- cobriStreamConnectors
- = new ArrayList<WeakReference<CobriStreamConnector>>(
+ colibriStreamConnectors
+ = new ArrayList<WeakReference<ColibriStreamConnector>>(
mediaTypeValueCount);
for (int i = 0; i < mediaTypeValueCount; i++)
- cobriStreamConnectors.add(null);
+ colibriStreamConnectors.add(null);
//let's add ourselves to the calls repo. we are doing it ourselves just
//to make sure that no one ever forgets.
@@ -86,23 +86,23 @@ public class CallJabberImpl
}
/**
- * Closes a specific <tt>CobriStreamConnector</tt> which is associated with
+ * Closes a specific <tt>ColibriStreamConnector</tt> which is associated with
* a <tt>MediaStream</tt> of a specific <tt>MediaType</tt> upon request from
* a specific <tt>CallPeer</tt>.
*
* @param peer the <tt>CallPeer</tt> which requests the closing of the
- * specified <tt>cobriStreamConnector</tt>
+ * specified <tt>colibriStreamConnector</tt>
* @param mediaType the <tt>MediaType</tt> of the <tt>MediaStream</tt> with
- * which the specified <tt>cobriStreamConnector</tt> is associated
- * @param cobriStreamConnector the <tt>CobriStreamConnector</tt> to close on
+ * which the specified <tt>colibriStreamConnector</tt> is associated
+ * @param colibriStreamConnector the <tt>ColibriStreamConnector</tt> to close on
* behalf of the specified <tt>peer</tt>
*/
- public void closeCobriStreamConnector(
+ public void closeColibriStreamConnector(
CallPeerJabberImpl peer,
MediaType mediaType,
- CobriStreamConnector cobriStreamConnector)
+ ColibriStreamConnector colibriStreamConnector)
{
- cobriStreamConnector.close();
+ colibriStreamConnector.close();
}
/**
@@ -134,19 +134,19 @@ public class CallJabberImpl
}
/**
- * Allocates cobri (conference) channels for a specific <tt>MediaType</tt>
+ * Allocates colibri (conference) channels for a specific <tt>MediaType</tt>
* to be used by a specific <tt>CallPeer</tt>.
*
- * @param peer the <tt>CallPeer</tt> which is to use the allocated cobri
+ * @param peer the <tt>CallPeer</tt> which is to use the allocated colibri
* (conference) channels
* @param rdpes the <tt>RtpDescriptionPacketExtension</tt>s which specify
- * the <tt>MediaType</tt>s for which cobri (conference) channels are to be
+ * the <tt>MediaType</tt>s for which colibri (conference) channels are to be
* allocated
- * @return a <tt>CobriConferenceIQ</tt> which describes the allocated cobri
+ * @return a <tt>ColibriConferenceIQ</tt> which describes the allocated colibri
* (conference) channels for the specified <tt>mediaTypes</tt> which are to
* be used by the specified <tt>peer</tt>; otherwise, <tt>null</tt>
*/
- public CobriConferenceIQ createCobriChannels(
+ public ColibriConferenceIQ createColibriChannels(
CallPeerJabberImpl peer,
Iterable<RtpDescriptionPacketExtension> rdpes)
{
@@ -154,14 +154,14 @@ public class CallJabberImpl
return null;
/*
- * For a cobri conference to work properly, all CallPeers in the
+ * For a colibri conference to work properly, all CallPeers in the
* conference must share one and the same CallPeerMediaHandler state
* i.e. they must use a single set of MediaStreams as if there was a
* single CallPeerMediaHandler.
*/
CallPeerMediaHandler<?> peerMediaHandler = peer.getMediaHandler();
- if (peerMediaHandler.getMediaHandler() != cobriMediaHandler)
+ if (peerMediaHandler.getMediaHandler() != colibriMediaHandler)
{
for (MediaType mediaType : MediaType.values())
if (peerMediaHandler.getStream(mediaType) != null)
@@ -171,49 +171,49 @@ public class CallJabberImpl
ProtocolProviderServiceJabberImpl protocolProvider
= getProtocolProvider();
String jitsiVideoBridge
- = (cobri == null)
+ = (colibri == null)
? protocolProvider.getJitsiVideoBridge()
- : cobri.getFrom();
+ : colibri.getFrom();
if ((jitsiVideoBridge == null) || (jitsiVideoBridge.length() == 0))
return null;
- CobriConferenceIQ conferenceRequest = new CobriConferenceIQ();
+ ColibriConferenceIQ conferenceRequest = new ColibriConferenceIQ();
- if (cobri != null)
- conferenceRequest.setID(cobri.getID());
+ if (colibri != null)
+ conferenceRequest.setID(colibri.getID());
for (RtpDescriptionPacketExtension rdpe : rdpes)
{
MediaType mediaType = MediaType.parseString(rdpe.getMedia());
String contentName = mediaType.toString();
- CobriConferenceIQ.Content contentRequest
- = new CobriConferenceIQ.Content(contentName);
+ ColibriConferenceIQ.Content contentRequest
+ = new ColibriConferenceIQ.Content(contentName);
conferenceRequest.addContent(contentRequest);
boolean requestLocalChannel = true;
- if (cobri != null)
+ if (colibri != null)
{
- CobriConferenceIQ.Content content
- = cobri.getContent(contentName);
+ ColibriConferenceIQ.Content content
+ = colibri.getContent(contentName);
if ((content != null) && (content.getChannelCount() > 0))
requestLocalChannel = false;
}
if (requestLocalChannel)
{
- CobriConferenceIQ.Channel localChannelRequest
- = new CobriConferenceIQ.Channel();
+ ColibriConferenceIQ.Channel localChannelRequest
+ = new ColibriConferenceIQ.Channel();
for (PayloadTypePacketExtension ptpe : rdpe.getPayloadTypes())
localChannelRequest.addPayloadType(ptpe);
contentRequest.addChannel(localChannelRequest);
}
- CobriConferenceIQ.Channel remoteChannelRequest
- = new CobriConferenceIQ.Channel();
+ ColibriConferenceIQ.Channel remoteChannelRequest
+ = new ColibriConferenceIQ.Channel();
for (PayloadTypePacketExtension ptpe : rdpe.getPayloadTypes())
remoteChannelRequest.addPayloadType(ptpe);
@@ -237,36 +237,36 @@ public class CallJabberImpl
if ((response == null)
|| (response.getError() != null)
- || !(response instanceof CobriConferenceIQ))
+ || !(response instanceof ColibriConferenceIQ))
return null;
- CobriConferenceIQ conferenceResponse = (CobriConferenceIQ) response;
+ ColibriConferenceIQ conferenceResponse = (ColibriConferenceIQ) response;
String conferenceResponseID = conferenceResponse.getID();
/*
- * Update the complete CobriConferenceIQ representation maintained by
+ * Update the complete ColibriConferenceIQ representation maintained by
* this instance with the information given by the (current) response.
*/
- if (cobri == null)
+ if (colibri == null)
{
- cobri = conferenceResponse;
+ colibri = conferenceResponse;
}
else
{
- String cobriID = cobri.getID();
+ String colibriID = colibri.getID();
- if (cobriID == null)
- cobri.setID(conferenceResponseID);
- else if (!cobriID.equals(conferenceResponseID))
+ if (colibriID == null)
+ colibri.setID(conferenceResponseID);
+ else if (!colibriID.equals(conferenceResponseID))
throw new IllegalStateException("conference.id");
- for (CobriConferenceIQ.Content contentResponse
+ for (ColibriConferenceIQ.Content contentResponse
: conferenceResponse.getContents())
{
- CobriConferenceIQ.Content content
- = cobri.getOrCreateContent(contentResponse.getName());
+ ColibriConferenceIQ.Content content
+ = colibri.getOrCreateContent(contentResponse.getName());
- for (CobriConferenceIQ.Channel channelResponse
+ for (ColibriConferenceIQ.Channel channelResponse
: contentResponse.getChannels())
content.addChannel(channelResponse);
}
@@ -279,21 +279,21 @@ public class CallJabberImpl
* explicitly requested by the method caller and their
* respective local channels.
*/
- CobriConferenceIQ conferenceResult = new CobriConferenceIQ();
+ ColibriConferenceIQ conferenceResult = new ColibriConferenceIQ();
conferenceResult.setID(conferenceResponseID);
for (RtpDescriptionPacketExtension rdpe : rdpes)
{
MediaType mediaType = MediaType.parseString(rdpe.getMedia());
- CobriConferenceIQ.Content contentResponse
+ ColibriConferenceIQ.Content contentResponse
= conferenceResponse.getContent(mediaType.toString());
if (contentResponse != null)
{
String contentName = contentResponse.getName();
- CobriConferenceIQ.Content contentResult
- = new CobriConferenceIQ.Content(contentName);
+ ColibriConferenceIQ.Content contentResult
+ = new ColibriConferenceIQ.Content(contentName);
conferenceResult.addContent(contentResult);
@@ -303,9 +303,9 @@ public class CallJabberImpl
* channel in the respective content. Anyway, the current method
* caller still needs to know about it.
*/
- CobriConferenceIQ.Content content
- = cobri.getContent(contentName);
- CobriConferenceIQ.Channel localChannel = null;
+ ColibriConferenceIQ.Content content
+ = colibri.getContent(contentName);
+ ColibriConferenceIQ.Channel localChannel = null;
if ((content != null) && (content.getChannelCount() > 0))
{
@@ -316,7 +316,7 @@ public class CallJabberImpl
String localChannelID
= (localChannel == null) ? null : localChannel.getID();
- for (CobriConferenceIQ.Channel channelResponse
+ for (ColibriConferenceIQ.Channel channelResponse
: contentResponse.getChannels())
{
if ((localChannelID == null)
@@ -327,50 +327,50 @@ public class CallJabberImpl
}
/*
- * The specified CallPeer will participate in the cobri conference
+ * The specified CallPeer will participate in the colibri conference
* organized by this Call so it must use the shared CallPeerMediaHandler
- * state of all CallPeers in the same cobri conference.
+ * state of all CallPeers in the same colibri conference.
*/
- if (cobriMediaHandler == null)
- cobriMediaHandler = new MediaHandler();
- peerMediaHandler.setMediaHandler(cobriMediaHandler);
+ if (colibriMediaHandler == null)
+ colibriMediaHandler = new MediaHandler();
+ peerMediaHandler.setMediaHandler(colibriMediaHandler);
return conferenceResult;
}
/**
- * Initializes a <tt>CobriStreamConnector</tt> on behalf of a specific
+ * Initializes a <tt>ColibriStreamConnector</tt> on behalf of a specific
* <tt>CallPeer</tt> to be used in association with a specific
- * <tt>CobriConferenceIQ.Channel</tt> of a specific <tt>MediaType</tt>.
+ * <tt>ColibriConferenceIQ.Channel</tt> of a specific <tt>MediaType</tt>.
*
* @param peer the <tt>CallPeer</tt> which requests the initialization of a
- * <tt>CobriStreamConnector</tt>
+ * <tt>ColibriStreamConnector</tt>
* @param mediaType the <tt>MediaType</tt> of the stream which is to use the
- * initialized <tt>CobriStreamConnector</tt> for RTP and RTCP traffic
- * @param channel the <tt>CobriConferenceIQ.Channel</tt> to which RTP and
+ * initialized <tt>ColibriStreamConnector</tt> for RTP and RTCP traffic
+ * @param channel the <tt>ColibriConferenceIQ.Channel</tt> to which RTP and
* RTCP traffic is to be sent and from which such traffic is to be received
- * via the initialized <tt>CobriStreamConnector</tt>
+ * via the initialized <tt>ColibriStreamConnector</tt>
* @param factory a <tt>StreamConnectorFactory</tt> implementation which is
* to allocate the sockets to be used for RTP and RTCP traffic
- * @return a <tt>CobriStreamConnector</tt> to be used for RTP and RTCP
+ * @return a <tt>ColibriStreamConnector</tt> to be used for RTP and RTCP
* traffic associated with the specified <tt>channel</tt>
*/
- public CobriStreamConnector createCobriStreamConnector(
- CallPeerJabberImpl peer,
- MediaType mediaType,
- CobriConferenceIQ.Channel channel,
- StreamConnectorFactory factory)
+ public ColibriStreamConnector createColibriStreamConnector(
+ CallPeerJabberImpl peer,
+ MediaType mediaType,
+ ColibriConferenceIQ.Channel channel,
+ StreamConnectorFactory factory)
{
String channelID = channel.getID();
if (channelID == null)
throw new IllegalArgumentException("channel");
- if (cobri == null)
- throw new IllegalStateException("cobri");
+ if (colibri == null)
+ throw new IllegalStateException("colibri");
- CobriConferenceIQ.Content content
- = cobri.getContent(mediaType.toString());
+ ColibriConferenceIQ.Content content
+ = colibri.getContent(mediaType.toString());
if (content == null)
throw new IllegalArgumentException("mediaType");
@@ -378,85 +378,85 @@ public class CallJabberImpl
|| !channelID.equals((channel = content.getChannel(0)).getID()))
throw new IllegalArgumentException("channel");
- CobriStreamConnector cobriStreamConnector;
+ ColibriStreamConnector colibriStreamConnector;
- synchronized (cobriStreamConnectors)
+ synchronized (colibriStreamConnectors)
{
int index = mediaType.ordinal();
- WeakReference<CobriStreamConnector> weakReference
- = cobriStreamConnectors.get(index);
+ WeakReference<ColibriStreamConnector> weakReference
+ = colibriStreamConnectors.get(index);
- cobriStreamConnector
+ colibriStreamConnector
= (weakReference == null) ? null : weakReference.get();
- if (cobriStreamConnector == null)
+ if (colibriStreamConnector == null)
{
StreamConnector streamConnector
= factory.createStreamConnector();
if (streamConnector != null)
{
- cobriStreamConnector
- = new CobriStreamConnector(streamConnector);
- cobriStreamConnectors.set(
- index,
- new WeakReference<CobriStreamConnector>(
- cobriStreamConnector));
+ colibriStreamConnector
+ = new ColibriStreamConnector(streamConnector);
+ colibriStreamConnectors.set(
+ index,
+ new WeakReference<ColibriStreamConnector>(
+ colibriStreamConnector));
}
}
}
- return cobriStreamConnector;
+ return colibriStreamConnector;
}
/**
- * Expires specific (cobri) conference channels used by a specific
+ * Expires specific (colibri) conference channels used by a specific
* <tt>CallPeer</tt>.
*
- * @param peer the <tt>CallPeer</tt> which uses the specified (cobri)
+ * @param peer the <tt>CallPeer</tt> which uses the specified (colibri)
* conference channels to be expired
- * @param conference a <tt>CobriConferenceIQ</tt> which specifies the
- * (cobri) conference channels to be expired
+ * @param conference a <tt>ColibriConferenceIQ</tt> which specifies the
+ * (colibri) conference channels to be expired
*/
- public void expireCobriChannels(
+ public void expireColibriChannels(
CallPeerJabberImpl peer,
- CobriConferenceIQ conference)
+ ColibriConferenceIQ conference)
{
- // Formulate the CobriConferenceIQ request which is to be sent.
- if (cobri != null)
+ // Formulate the ColibriConferenceIQ request which is to be sent.
+ if (colibri != null)
{
- String conferenceID = cobri.getID();
+ String conferenceID = colibri.getID();
if (conferenceID.equals(conference.getID()))
{
- CobriConferenceIQ conferenceRequest = new CobriConferenceIQ();
+ ColibriConferenceIQ conferenceRequest = new ColibriConferenceIQ();
conferenceRequest.setID(conferenceID);
- for (CobriConferenceIQ.Content content
+ for (ColibriConferenceIQ.Content content
: conference.getContents())
{
- CobriConferenceIQ.Content cobriContent
- = cobri.getContent(content.getName());
+ ColibriConferenceIQ.Content colibriContent
+ = colibri.getContent(content.getName());
- if (cobriContent != null)
+ if (colibriContent != null)
{
- CobriConferenceIQ.Content contentRequest
+ ColibriConferenceIQ.Content contentRequest
= conferenceRequest.getOrCreateContent(
- cobriContent.getName());
+ colibriContent.getName());
- for (CobriConferenceIQ.Channel channel
+ for (ColibriConferenceIQ.Channel channel
: content.getChannels())
{
- CobriConferenceIQ.Channel cobriChannel
- = cobriContent.getChannel(channel.getID());
+ ColibriConferenceIQ.Channel colibriChannel
+ = colibriContent.getChannel(channel.getID());
- if (cobriChannel != null)
+ if (colibriChannel != null)
{
- CobriConferenceIQ.Channel channelRequest
- = new CobriConferenceIQ.Channel();
+ ColibriConferenceIQ.Channel channelRequest
+ = new ColibriConferenceIQ.Channel();
channelRequest.setExpire(0);
- channelRequest.setID(cobriChannel.getID());
+ channelRequest.setID(colibriChannel.getID());
contentRequest.addChannel(channelRequest);
}
}
@@ -467,34 +467,34 @@ public class CallJabberImpl
* Remove the channels which are to be expired from the internal
* state of the conference managed by this CallJabberImpl.
*/
- for (CobriConferenceIQ.Content contentRequest
+ for (ColibriConferenceIQ.Content contentRequest
: conferenceRequest.getContents())
{
- CobriConferenceIQ.Content cobriContent
- = cobri.getContent(contentRequest.getName());
+ ColibriConferenceIQ.Content colibriContent
+ = colibri.getContent(contentRequest.getName());
- for (CobriConferenceIQ.Channel channelRequest
+ for (ColibriConferenceIQ.Channel channelRequest
: contentRequest.getChannels())
{
- CobriConferenceIQ.Channel cobriChannel
- = cobriContent.getChannel(channelRequest.getID());
+ ColibriConferenceIQ.Channel colibriChannel
+ = colibriContent.getChannel(channelRequest.getID());
- cobriContent.removeChannel(cobriChannel);
+ colibriContent.removeChannel(colibriChannel);
/*
* If the last remote channel is to be expired, expire
* the local channel as well.
*/
- if (cobriContent.getChannelCount() == 1)
+ if (colibriContent.getChannelCount() == 1)
{
- cobriChannel = cobriContent.getChannel(0);
+ colibriChannel = colibriContent.getChannel(0);
- channelRequest = new CobriConferenceIQ.Channel();
+ channelRequest = new ColibriConferenceIQ.Channel();
channelRequest.setExpire(0);
- channelRequest.setID(cobriChannel.getID());
+ channelRequest.setID(colibriChannel.getID());
contentRequest.addChannel(channelRequest);
- cobriContent.removeChannel(cobriChannel);
+ colibriContent.removeChannel(colibriChannel);
break;
}
@@ -502,10 +502,10 @@ public class CallJabberImpl
}
/*
- * At long last, send the CobriConferenceIQ request to expire
+ * At long last, send the ColibriConferenceIQ request to expire
* the channels.
*/
- conferenceRequest.setTo(cobri.getFrom());
+ conferenceRequest.setTo(colibri.getFrom());
conferenceRequest.setType(IQ.Type.SET);
getProtocolProvider().getConnection().sendPacket(
conferenceRequest);
@@ -608,24 +608,24 @@ public class CallJabberImpl
}
/**
- * Notifies this instance that a specific <tt>CobriConferenceIQ</tt> has
+ * Notifies this instance that a specific <tt>ColibriConferenceIQ</tt> has
* been received.
*
- * @param conferenceIQ the <tt>CobriConferenceIQ</tt> which has been
+ * @param conferenceIQ the <tt>ColibriConferenceIQ</tt> which has been
* received
* @return <tt>true</tt> if the specified <tt>conferenceIQ</tt> was
* processed by this instance and no further processing is to be performed
- * by other possible processors of <tt>CobriConferenceIQ</tt>s; otherwise,
- * <tt>false</tt>. Because a <tt>CobriConferenceIQ</tt> request sent from
+ * by other possible processors of <tt>ColibriConferenceIQ</tt>s; otherwise,
+ * <tt>false</tt>. Because a <tt>ColibriConferenceIQ</tt> request sent from
* the Jitsi VideoBridge server to the application as its client concerns a
* specific <tt>CallJabberImpl</tt> implementation, no further processing by
* other <tt>CallJabberImpl</tt> instances is necessary once the
- * <tt>CobriConferenceIQ</tt> is processed by the associated
+ * <tt>ColibriConferenceIQ</tt> is processed by the associated
* <tt>CallJabberImpl</tt> instance.
*/
- boolean processCobriConferenceIQ(CobriConferenceIQ conferenceIQ)
+ boolean processColibriConferenceIQ(ColibriConferenceIQ conferenceIQ)
{
- if (cobri == null)
+ if (colibri == null)
{
/*
* This instance has not set up any conference using the Jitsi
@@ -634,7 +634,7 @@ public class CallJabberImpl
*/
return false;
}
- else if (conferenceIQ.getID().equals(cobri.getID()))
+ else if (conferenceIQ.getID().equals(colibri.getID()))
{
/*
* Remove the local Channels (from the specified conferenceIQ) i.e.
@@ -645,20 +645,20 @@ public class CallJabberImpl
for (MediaType mediaType : MediaType.values())
{
String contentName = mediaType.toString();
- CobriConferenceIQ.Content content
+ ColibriConferenceIQ.Content content
= conferenceIQ.getContent(contentName);
if (content != null)
{
- CobriConferenceIQ.Content thisContent
- = cobri.getContent(contentName);
+ ColibriConferenceIQ.Content thisContent
+ = colibri.getContent(contentName);
if ((thisContent != null)
&& (thisContent.getChannelCount() > 0))
{
- CobriConferenceIQ.Channel thisChannel
+ ColibriConferenceIQ.Channel thisChannel
= thisContent.getChannel(0);
- CobriConferenceIQ.Channel channel
+ ColibriConferenceIQ.Channel channel
= content.getChannel(thisChannel.getID());
if (channel != null)
@@ -668,7 +668,7 @@ public class CallJabberImpl
}
for (CallPeerJabberImpl callPeer : getCallPeerList())
- callPeer.processCobriConferenceIQ(conferenceIQ);
+ callPeer.processColibriConferenceIQ(conferenceIQ);
/*
* We have removed the local Channels from the specified
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/ProtocolProviderServiceJabberImpl.java b/src/net/java/sip/communicator/impl/protocol/jabber/ProtocolProviderServiceJabberImpl.java
index 2fc417a..06078dd 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/ProtocolProviderServiceJabberImpl.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/ProtocolProviderServiceJabberImpl.java
@@ -18,7 +18,7 @@ import javax.net.ssl.*;
import net.java.sip.communicator.impl.protocol.jabber.debugger.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.caps.*;
-import net.java.sip.communicator.impl.protocol.jabber.extensions.cobri.*;
+import net.java.sip.communicator.impl.protocol.jabber.extensions.colibri.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.coin.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.gtalk.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.inputevt.*;
@@ -1679,18 +1679,18 @@ public class ProtocolProviderServiceJabberImpl
// Jitsi VideoBridge IQProvider and PacketExtensionProvider
providerManager.addIQProvider(
- CobriConferenceIQ.ELEMENT_NAME,
- CobriConferenceIQ.NAMESPACE,
- new CobriIQProvider());
+ ColibriConferenceIQ.ELEMENT_NAME,
+ ColibriConferenceIQ.NAMESPACE,
+ new ColibriIQProvider());
providerManager.addExtensionProvider(
PayloadTypePacketExtension.ELEMENT_NAME,
- CobriConferenceIQ.NAMESPACE,
+ ColibriConferenceIQ.NAMESPACE,
new DefaultPacketExtensionProvider<
PayloadTypePacketExtension>(
PayloadTypePacketExtension.class));
providerManager.addExtensionProvider(
ParameterPacketExtension.ELEMENT_NAME,
- CobriConferenceIQ.NAMESPACE,
+ ColibriConferenceIQ.NAMESPACE,
new DefaultPacketExtensionProvider<
ParameterPacketExtension>(
ParameterPacketExtension.class));
@@ -2754,7 +2754,7 @@ public class ProtocolProviderServiceJabberImpl
}
if ((discoverInfo != null)
&& discoverInfo.containsFeature(
- CobriConferenceIQ.NAMESPACE))
+ ColibriConferenceIQ.NAMESPACE))
{
return entityID;
}
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/CallPeerJabberImpl.java b/src/net/java/sip/communicator/impl/protocol/jabber/CallPeerJabberImpl.java
index 6acf88c..6c49d4c 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/CallPeerJabberImpl.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/CallPeerJabberImpl.java
@@ -9,7 +9,7 @@ package net.java.sip.communicator.impl.protocol.jabber;
import java.lang.reflect.*;
import java.util.*;
-import net.java.sip.communicator.impl.protocol.jabber.extensions.cobri.*;
+import net.java.sip.communicator.impl.protocol.jabber.extensions.colibri.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.jingle.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.jingle.ContentPacketExtension.SendersEnum;
import net.java.sip.communicator.impl.protocol.jabber.jinglesdp.*;
@@ -365,15 +365,15 @@ public class CallPeerJabberImpl
}
/**
* Notifies this instance that a specific <tt>CobriConferenceIQ</tt> has
* been received. This <tt>CallPeerJabberImpl</tt> uses the part of the
* information provided in the specified <tt>conferenceIQ</tt> which
* concerns it only.
*
* @param conferenceIQ the <tt>CobriConferenceIQ</tt> which has been
* received
*/
- void processCobriConferenceIQ(CobriConferenceIQ conferenceIQ)
+ void processColibriConferenceIQ(ColibriConferenceIQ conferenceIQ)
{
/*
* CallPeerJabberImpl does not itself/directly know the specifics
@@ -381,7 +381,7 @@ public class CallPeerJabberImpl
* The channels contain transport and media-related information so
* forward the notification to CallPeerMediaHandlerJabberImpl.
*/
- getMediaHandler().processCobriConferenceIQ(conferenceIQ);
+ getMediaHandler().processColibriConferenceIQ(conferenceIQ);
}
/**
@@ -365,15 +365,15 @@ public class CallPeerJabberImpl
}
/**
- * Notifies this instance that a specific <tt>CobriConferenceIQ</tt> has
+ * Notifies this instance that a specific <tt>ColibriConferenceIQ</tt> has
* been received. This <tt>CallPeerJabberImpl</tt> uses the part of the
* information provided in the specified <tt>conferenceIQ</tt> which
@@ -365,15 +365,15 @@ public class CallPeerJabberImpl
* concerns it only.
*
- * @param conferenceIQ the <tt>CobriConferenceIQ</tt> which has been
+ * @param conferenceIQ the <tt>ColibriConferenceIQ</tt> which has been
* received
*/
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/CallPeerMediaHandlerJabberImpl.java b/src/net/java/sip/communicator/impl/protocol/jabber/CallPeerMediaHandlerJabberImpl.java
index 2edd140..a2a9d9e 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/CallPeerMediaHandlerJabberImpl.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/CallPeerMediaHandlerJabberImpl.java
@@ -11,7 +11,7 @@ import java.lang.reflect.*;
import java.util.*;
import java.util.List;
-import net.java.sip.communicator.impl.protocol.jabber.extensions.cobri.*;
+import net.java.sip.communicator.impl.protocol.jabber.extensions.colibri.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.jingle.*;
import net.java.sip.communicator.impl.protocol.jabber.jinglesdp.*;
import net.java.sip.communicator.service.protocol.*;
@@ -772,10 +772,10 @@ public class CallPeerMediaHandlerJabberImpl
{
RawUdpTransportManager rawUdpTransportManager
= (RawUdpTransportManager) transportManager;
- CobriConferenceIQ.Channel channel
- = rawUdpTransportManager.getCobriChannel(
- mediaType,
- false /* remote */);
+ ColibriConferenceIQ.Channel channel
+ = rawUdpTransportManager.getColibriChannel(
+ mediaType,
+ false /* remote */);
if (channel != null)
return channel.getSSRCs();
@@ -788,7 +788,7 @@ public class CallPeerMediaHandlerJabberImpl
*/
long ssrc = super.getRemoteSSRC(mediaType);
- return (ssrc == -1) ? CobriConferenceIQ.NO_SSRCS : new long[] { ssrc };
+ return (ssrc == -1) ? ColibriConferenceIQ.NO_SSRCS : new long[] { ssrc };
}
/**
@@ -1198,21 +1198,21 @@ public class CallPeerMediaHandlerJabberImpl
}
/**
* Notifies this instance that a specific <tt>CobriConferenceIQ</tt> has
* been received. This <tt>CallPeerMediaHandler</tt> uses the part of the
* information provided in the specified <tt>conferenceIQ</tt> which
* concerns it only.
*
* @param conferenceIQ the <tt>CobriConferenceIQ</tt> which has been
* received
*/
- void processCobriConferenceIQ(CobriConferenceIQ conferenceIQ)
+ void processColibriConferenceIQ(ColibriConferenceIQ conferenceIQ)
{
/*
* This CallPeerMediaHandler stores the media information but it does
* not store the cobri Channels (which contain both media and transport
* information). The TransportManager associated with this instance
* stores the cobri Channels but does not store media information (such
* as the remote SSRCs). An design/implementation choice has to be made
* though and the present one is to have this CallPeerMediaHandler
* transparently (with respect to the TransportManager) store the media
@@ -1229,19 +1229,19 @@ public class CallPeerMediaHandlerJabberImpl
for (MediaType mediaType : MediaType.values())
{
- CobriConferenceIQ.Channel dst
- = rawUdpTransportManager.getCobriChannel(
- mediaType,
- false /* remote */);
+ ColibriConferenceIQ.Channel dst
+ = rawUdpTransportManager.getColibriChannel(
+ mediaType,
+ false /* remote */);
if (dst != null)
{
- CobriConferenceIQ.Content content
+ ColibriConferenceIQ.Content content
= conferenceIQ.getContent(mediaType.toString());
if (content != null)
{
- CobriConferenceIQ.Channel src
+ ColibriConferenceIQ.Channel src
= content.getChannel(dst.getID());
if (src != null)
@@ -1198,21 +1198,21 @@ public class CallPeerMediaHandlerJabberImpl
}
/**
- * Notifies this instance that a specific <tt>CobriConferenceIQ</tt> has
+ * Notifies this instance that a specific <tt>ColibriConferenceIQ</tt> has
* been received. This <tt>CallPeerMediaHandler</tt> uses the part of the
* information provided in the specified <tt>conferenceIQ</tt> which
@@ -1198,21 +1198,21 @@ public class CallPeerMediaHandlerJabberImpl
* concerns it only.
*
- * @param conferenceIQ the <tt>CobriConferenceIQ</tt> which has been
+ * @param conferenceIQ the <tt>ColibriConferenceIQ</tt> which has been
* received
*/
@@ -1198,21 +1198,21 @@ public class CallPeerMediaHandlerJabberImpl
/*
* This CallPeerMediaHandler stores the media information but it does
- * not store the cobri Channels (which contain both media and transport
+ * not store the colibri Channels (which contain both media and transport
* information). The TransportManager associated with this instance
@@ -1198,21 +1198,21 @@ public class CallPeerMediaHandlerJabberImpl
* information). The TransportManager associated with this instance
- * stores the cobri Channels but does not store media information (such
+ * stores the colibri Channels but does not store media information (such
* as the remote SSRCs). An design/implementation choice has to be made
* though and the present one is to have this CallPeerMediaHandler
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/OperationSetVideoBridgeImpl.java b/src/net/java/sip/communicator/impl/protocol/jabber/OperationSetVideoBridgeImpl.java
index f4ff56b..01232f3 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/OperationSetVideoBridgeImpl.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/OperationSetVideoBridgeImpl.java
@@ -8,7 +8,7 @@ package net.java.sip.communicator.impl.protocol.jabber;
import java.util.*;
-import net.java.sip.communicator.impl.protocol.jabber.extensions.cobri.*;
+import net.java.sip.communicator.impl.protocol.jabber.extensions.colibri.*;
import net.java.sip.communicator.service.protocol.*;
import net.java.sip.communicator.service.protocol.event.*;
import net.java.sip.communicator.service.protocol.media.*;
@@ -61,17 +61,17 @@ public class OperationSetVideoBridgeImpl
* Implements {@link PacketFilter}. Determines whether this instance is
* interested in a specific {@link Packet}.
* <tt>OperationSetVideoBridgeImpl</tt> returns <tt>true</tt> if the
- * specified <tt>packet</tt> is a {@link CobriConferenceIQ}; otherwise,
+ * specified <tt>packet</tt> is a {@link net.java.sip.communicator.impl.protocol.jabber.extensions.colibri.ColibriConferenceIQ}; otherwise,
* <tt>false</tt>.
*
* @param packet the <tt>Packet</tt> to be determined whether this instance
* is interested in it
* @return <tt>true</tt> if the specified <tt>packet</tt> is a
- * <tt>CobriConferenceIQ</tt>; otherwise, <tt>false</tt>
+ * <tt>ColibriConferenceIQ</tt>; otherwise, <tt>false</tt>
*/
public boolean accept(Packet packet)
{
- return (packet instanceof CobriConferenceIQ);
+ return (packet instanceof ColibriConferenceIQ);
}
/**
@@ -139,24 +139,24 @@ public class OperationSetVideoBridgeImpl
}
/**
* Notifies this instance that a specific <tt>CobriConferenceIQ</tt> has
* been received.
*
* @param conferenceIQ the <tt>CobriConferenceIQ</tt> which has been
* received
*/
- private void processCobriConferenceIQ(CobriConferenceIQ conferenceIQ)
+ private void processColibriConferenceIQ(ColibriConferenceIQ conferenceIQ)
{
/*
* The application is not a Jitsi VideoBridge server, it is a client.
* Consequently, the specified CobriConferenceIQ is sent to it in
* relation to the part of the application's functionality which makes
* requests to a Jitsi VideoBridge server i.e. CallJabberImpl.
*
* Additionally, the method processCobriConferenceIQ is presently tasked
* with processing CobriConferenceIQ requests only. They are SET IQs
* sent by the Jitsi VideoBridge server to notify the application about
* updates in the states of (cobri) conferences organized by the
* application.
*/
if (IQ.Type.SET.equals(conferenceIQ.getType())
@@ -189,8 +189,8 @@ public class OperationSetVideoBridgeImpl
* the conferenceIQ from reaching the CallJabberImpl
* instance which it was meant for.
*/
- callJabberImpl.processCobriConferenceIQ(
- conferenceIQ);
+ callJabberImpl.processColibriConferenceIQ(
+ conferenceIQ);
break;
}
}
@@ -223,12 +223,12 @@ public class OperationSetVideoBridgeImpl
* Now that the acknowledging is out of the way, do go about our
* business with the Packet.
*/
- CobriConferenceIQ conferenceIQ = (CobriConferenceIQ) iq;
+ ColibriConferenceIQ conferenceIQ = (ColibriConferenceIQ) iq;
boolean interrupted = false;
try
{
- processCobriConferenceIQ(conferenceIQ);
+ processColibriConferenceIQ(conferenceIQ);
}
catch (Throwable t)
{
@@ -262,7 +262,7 @@ public class OperationSetVideoBridgeImpl
* Implements {@link RegistrationStateChangeListener}. Notifies this
* instance that there has been a change in the <tt>RegistrationState</tt>
* of {@link #protocolProvider}. Subscribes this instance to
- * {@link CobriConferenceIQ}s as soon as <tt>protocolProvider</tt> is
+ * {@link net.java.sip.communicator.impl.protocol.jabber.extensions.colibri.ColibriConferenceIQ}s as soon as <tt>protocolProvider</tt> is
* registered and unsubscribes it as soon as <tt>protocolProvider</tt> is
* unregistered.
*/
@@ -139,24 +139,24 @@ public class OperationSetVideoBridgeImpl
}
/**
- * Notifies this instance that a specific <tt>CobriConferenceIQ</tt> has
+ * Notifies this instance that a specific <tt>ColibriConferenceIQ</tt> has
* been received.
*
@@ -139,24 +139,24 @@ public class OperationSetVideoBridgeImpl
* been received.
*
- * @param conferenceIQ the <tt>CobriConferenceIQ</tt> which has been
+ * @param conferenceIQ the <tt>ColibriConferenceIQ</tt> which has been
* received
*/
@@ -139,24 +139,24 @@ public class OperationSetVideoBridgeImpl
/*
* The application is not a Jitsi VideoBridge server, it is a client.
- * Consequently, the specified CobriConferenceIQ is sent to it in
+ * Consequently, the specified ColibriConferenceIQ is sent to it in
* relation to the part of the application's functionality which makes
* requests to a Jitsi VideoBridge server i.e. CallJabberImpl.
@@ -139,24 +139,24 @@ public class OperationSetVideoBridgeImpl
* requests to a Jitsi VideoBridge server i.e. CallJabberImpl.
*
- * Additionally, the method processCobriConferenceIQ is presently tasked
- * with processing CobriConferenceIQ requests only. They are SET IQs
+ * Additionally, the method processColibriConferenceIQ is presently tasked
+ * with processing ColibriConferenceIQ requests only. They are SET IQs
* sent by the Jitsi VideoBridge server to notify the application about
@@ -139,24 +139,24 @@ public class OperationSetVideoBridgeImpl
* sent by the Jitsi VideoBridge server to notify the application about
- * updates in the states of (cobri) conferences organized by the
+ * updates in the states of (colibri) conferences organized by the
* application.
*/
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/RawUdpTransportManager.java b/src/net/java/sip/communicator/impl/protocol/jabber/RawUdpTransportManager.java
index 6af0f58..6326c00 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/RawUdpTransportManager.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/RawUdpTransportManager.java
@@ -9,7 +9,7 @@ package net.java.sip.communicator.impl.protocol.jabber;
import java.net.*;
import java.util.*;
-import net.java.sip.communicator.impl.protocol.jabber.extensions.cobri.*;
+import net.java.sip.communicator.impl.protocol.jabber.extensions.colibri.*;
import net.java.sip.communicator.impl.protocol.jabber.extensions.jingle.*;
import net.java.sip.communicator.impl.protocol.jabber.jinglesdp.*;
import net.java.sip.communicator.service.protocol.*;
@@ -47,7 +47,7 @@ public class RawUdpTransportManager
* <tt>CallJabberImpl</tt> which provides information specific to this
* <tt>RawUdpTransportManager</tt> only.
*/
- private CobriConferenceIQ cobri;
+ private ColibriConferenceIQ colibri;
/**
* Creates a new instance of this transport manager, binding it to the
@@ -79,7 +79,7 @@ public class RawUdpTransportManager
{
boolean superCloseStreamConnector = true;
- if (streamConnector instanceof CobriStreamConnector)
+ if (streamConnector instanceof ColibriStreamConnector)
{
CallPeerJabberImpl peer = getCallPeer();
@@ -90,10 +90,10 @@ public class RawUdpTransportManager
if (call != null)
{
superCloseStreamConnector = false;
- call.closeCobriStreamConnector(
- peer,
- mediaType,
- (CobriStreamConnector) streamConnector);
+ call.closeColibriStreamConnector(
+ peer,
+ mediaType,
+ (ColibriStreamConnector) streamConnector);
}
}
}
@@ -103,27 +103,27 @@ public class RawUdpTransportManager
finally
{
/*
* Expire the CobriConferenceIQ.Channel associated with the closed
* StreamConnector.
*/
- if (cobri != null)
+ if (colibri != null)
{
- CobriConferenceIQ.Content content
- = cobri.getContent(mediaType.toString());
+ ColibriConferenceIQ.Content content
+ = colibri.getContent(mediaType.toString());
if (content != null)
{
- List<CobriConferenceIQ.Channel> channels
+ List<ColibriConferenceIQ.Channel> channels
= content.getChannels();
if (channels.size() == 2)
{
- CobriConferenceIQ requestConferenceIQ
- = new CobriConferenceIQ();
+ ColibriConferenceIQ requestConferenceIQ
+ = new ColibriConferenceIQ();
- requestConferenceIQ.setID(cobri.getID());
+ requestConferenceIQ.setID(colibri.getID());
- CobriConferenceIQ.Content requestContent
+ ColibriConferenceIQ.Content requestContent
= requestConferenceIQ.getOrCreateContent(
content.getName());
@@ -136,7 +136,7 @@ public class RawUdpTransportManager
* RawUdpTransportManager allocates a single channel per
* MediaType, consider the whole Content expired.
*/
- cobri.removeContent(content);
+ colibri.removeContent(content);
CallPeerJabberImpl peer = getCallPeer();
@@ -145,9 +145,9 @@ public class RawUdpTransportManager
CallJabberImpl call = peer.getCall();
if (call != null)
- call.expireCobriChannels(
- peer,
- requestConferenceIQ);
+ call.expireColibriChannels(
+ peer,
+ requestConferenceIQ);
}
}
}
@@ -169,35 +169,36 @@ public class RawUdpTransportManager
protected StreamConnector createStreamConnector(final MediaType mediaType)
throws OperationFailedException
{
- CobriConferenceIQ.Channel channel = getCobriChannel(mediaType, true);
+ ColibriConferenceIQ.Channel channel
+ = getColibriChannel(mediaType, true);
if (channel != null)
{
CallPeerJabberImpl peer = getCallPeer();
CallJabberImpl call = peer.getCall();
StreamConnector streamConnector
- = call.createCobriStreamConnector(
- peer,
- mediaType,
- channel,
- new StreamConnectorFactory()
+ = call.createColibriStreamConnector(
+ peer,
+ mediaType,
+ channel,
+ new StreamConnectorFactory()
+ {
+ public StreamConnector createStreamConnector()
+ {
+ try
+ {
+ return
+ RawUdpTransportManager
+ .super
+ .createStreamConnector(
+ mediaType);
+ }
+ catch (OperationFailedException ofe)
{
- public StreamConnector createStreamConnector()
- {
- try
- {
- return
- RawUdpTransportManager
- .super
- .createStreamConnector(
- mediaType);
- }
- catch (OperationFailedException ofe)
- {
- return null;
- }
- }
- });
+ return null;
+ }
+ }
+ });
if (streamConnector != null)
return streamConnector;
@@ -222,7 +223,8 @@ public class RawUdpTransportManager
MediaType mediaType,
StreamConnector connector)
{
- CobriConferenceIQ.Channel channel = getCobriChannel(mediaType, false);
+ ColibriConferenceIQ.Channel channel = getColibriChannel(mediaType,
+ false);
RawUdpTransportPacketExtension ourTransport
= new RawUdpTransportPacketExtension();
@@ -306,8 +308,8 @@ public class RawUdpTransportManager
if (mediaType.equals(contentMediaType))
{
- CobriConferenceIQ.Channel channel
- = getCobriChannel(mediaType, true);
+ ColibriConferenceIQ.Channel channel
+ = getColibriChannel(mediaType, true);
if (channel == null)
{
@@ -334,39 +336,39 @@ public class RawUdpTransportManager
}
/**
- * Gets the {@link CobriConferenceIQ.Channel} which belongs to a content
+ * Gets the {@link net.java.sip.communicator.impl.protocol.jabber.extensions.colibri.ColibriConferenceIQ.Channel} which belongs to a content
* associated with a specific <tt>MediaType</tt> and is to be either locally
* or remotely used.
* <p>
* <b>Note</b>: Modifications to the <tt>CobriConferenceIQ.Channel</tt>
* instance returned by the method propagate to (the state of) this
* instance.
* </p>
*
* @param mediaType the <tt>MediaType</tt> associated with the content which
* contains the <tt>CobriConferenceIQ.Channel</tt> to get
* @param local <tt>true</tt> if the <tt>CobriConferenceIQ.Channel</tt>
* which is to be used locally is to be returned or <tt>false</tt> for the
* one which is to be used remotely
* @return the <tt>CobriConferenceIQ.Channel</tt> which belongs to a content
* associated with the specified <tt>mediaType</tt> and which is to be used
* in accord with the specified <tt>local</tt> indicator if such a channel
* exists; otherwise, <tt>null</tt>
*/
- CobriConferenceIQ.Channel getCobriChannel(
- MediaType mediaType,
- boolean local)
+ ColibriConferenceIQ.Channel getColibriChannel(
+ MediaType mediaType,
+ boolean local)
{
- CobriConferenceIQ.Channel channel = null;
+ ColibriConferenceIQ.Channel channel = null;
- if (cobri != null)
+ if (colibri != null)
{
- CobriConferenceIQ.Content content
- = cobri.getContent(mediaType.toString());
+ ColibriConferenceIQ.Content content
+ = colibri.getContent(mediaType.toString());
if (content != null)
{
- List<CobriConferenceIQ.Channel> channels
+ List<ColibriConferenceIQ.Channel> channels
= content.getChannels();
if (channels.size() == 2)
@@ -524,8 +526,8 @@ public class RawUdpTransportManager
* of the existence of channels in it signals that a channel
* allocation request has already been sent for that mediaType.
*/
- if ((cobri == null)
- || (cobri.getContent(mediaType.toString()) == null))
+ if ((colibri == null)
+ || (colibri.getContent(mediaType.toString()) == null))
{
if (!mediaTypes.contains(rtpDesc))
mediaTypes.add(rtpDesc);
@@ -538,32 +540,32 @@ public class RawUdpTransportManager
* mediaTypes. Regardless of the response, we do not want to
* repeat these requests.
*/
- if (cobri == null)
- cobri = new CobriConferenceIQ();
+ if (colibri == null)
+ colibri = new ColibriConferenceIQ();
for (RtpDescriptionPacketExtension mediaType : mediaTypes)
- cobri.getOrCreateContent(mediaType.getMedia());
+ colibri.getOrCreateContent(mediaType.getMedia());
- CobriConferenceIQ conferenceResult
- = call.createCobriChannels(peer, mediaTypes);
+ ColibriConferenceIQ conferenceResult
+ = call.createColibriChannels(peer, mediaTypes);
if (conferenceResult != null)
{
- String videoBridgeID = cobri.getID();
+ String videoBridgeID = colibri.getID();
String conferenceResultID = conferenceResult.getID();
if (videoBridgeID == null)
- cobri.setID(conferenceResultID);
+ colibri.setID(conferenceResultID);
else if (!videoBridgeID.equals(conferenceResultID))
throw new IllegalStateException("conference.id");
- for (CobriConferenceIQ.Content contentResult
+ for (ColibriConferenceIQ.Content contentResult
: conferenceResult.getContents())
{
- CobriConferenceIQ.Content content
- = cobri.getOrCreateContent(
+ ColibriConferenceIQ.Content content
+ = colibri.getOrCreateContent(
contentResult.getName());
- for (CobriConferenceIQ.Channel channelResult
+ for (ColibriConferenceIQ.Channel channelResult
: contentResult.getChannels())
{
if (content.getChannel(channelResult.getID())
@@ -103,27 +103,27 @@ public class RawUdpTransportManager
{
/*
- * Expire the CobriConferenceIQ.Channel associated with the closed
+ * Expire the ColibriConferenceIQ.Channel associated with the closed
* StreamConnector.
*/
@@ -334,39 +336,39 @@ public class RawUdpTransportManager
* or remotely used.
* <p>
- * <b>Note</b>: Modifications to the <tt>CobriConferenceIQ.Channel</tt>
+ * <b>Note</b>: Modifications to the <tt>ColibriConferenceIQ.Channel</tt>
* instance returned by the method propagate to (the state of) this
* instance.
@@ -334,39 +336,39 @@ public class RawUdpTransportManager
*
* @param mediaType the <tt>MediaType</tt> associated with the content which
- * contains the <tt>CobriConferenceIQ.Channel</tt> to get
- * @param local <tt>true</tt> if the <tt>CobriConferenceIQ.Channel</tt>
+ * contains the <tt>ColibriConferenceIQ.Channel</tt> to get
+ * @param local <tt>true</tt> if the <tt>ColibriConferenceIQ.Channel</tt>
* which is to be used locally is to be returned or <tt>false</tt> for the
* one which is to be used remotely
@@ -334,39 +336,39 @@ public class RawUdpTransportManager
* which is to be used locally is to be returned or <tt>false</tt> for the
* one which is to be used remotely
- * @return the <tt>CobriConferenceIQ.Channel</tt> which belongs to a content
+ * @return the <tt>ColibriConferenceIQ.Channel</tt> which belongs to a content
* associated with the specified <tt>mediaType</tt> and which is to be used
* in accord with the specified <tt>local</tt> indicator if such a channel
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/extensions/cobri/CobriConferenceIQ.java b/src/net/java/sip/communicator/impl/protocol/jabber/extensions/colibri/ColibriConferenceIQ.java
index 5831510..b86df2a 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/extensions/cobri/CobriConferenceIQ.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/extensions/colibri/ColibriConferenceIQ.java
@@ -4,7 +4,7 @@
* Distributable under LGPL license.
* See terms of license at gnu.org.
*/
-package net.java.sip.communicator.impl.protocol.jabber.extensions.cobri;
+package net.java.sip.communicator.impl.protocol.jabber.extensions.colibri;
import java.util.*;
@@ -13,11 +13,12 @@ import net.java.sip.communicator.impl.protocol.jabber.extensions.jingle.*;
import org.jivesoftware.smack.packet.*;
/**
- * Implements the Jitsi VideoBridge <tt>conference</tt> IQ.
+ * Implements the Jitsi VideoBridge <tt>conference</tt> IQ within the
+ * COnferencing with LIghtweight BRIdging.
*
* @author Lyubomir Marinov
*/
-public class CobriConferenceIQ
+public class ColibriConferenceIQ
extends IQ
{
/**
@@ -28,15 +29,16 @@ public class CobriConferenceIQ
/**
* The XML name of the <tt>id</tt> attribute of the Jitsi VideoBridge
* <tt>conference</tt> IQ which represents the value of the <tt>id</tt>
- * property of <tt>CobriConferenceIQ</tt>.
+ * property of <tt>ColibriConferenceIQ</tt>.
*/
public static final String ID_ATTR_NAME = "id";
/**
- * The XML namespace of the Jitsi VideoBridge <tt>conference</tt> IQ.
+ * The XML COnferencing with LIghtweight BRIdging namespace of the Jitsi
+ * VideoBridge <tt>conference</tt> IQ.
*/
public static final String NAMESPACE
- = "http://jitsi.org/protocol/videobridge#conference";
+ = "http://jitsi.org/protocol/colibri";
/**
* An array of <tt>long</tt>s which represents the lack of any (RTP) SSRCs
@@ -230,13 +232,13 @@ public class CobriConferenceIQ
* The XML name of the <tt>expire</tt> attribute of a <tt>channel</tt>
* of a <tt>content</tt> of a <tt>conference</tt> IQ which represents
* the value of the <tt>expire</tt> property of
- * <tt>CobriConferenceIQ.Channel</tt>.
+ * <tt>ColibriConferenceIQ.Channel</tt>.
*/
public static final String EXPIRE_ATTR_NAME = "expire";
/**
* The value of the <tt>expire</tt> property of
* <tt>CobriConferenceIQ.Channel</tt> which indicates that no actual
* value has been specified for the property in question.
*/
public static final int EXPIRE_NOT_SPECIFIED = -1;
@@ -245,7 +247,7 @@ public class CobriConferenceIQ
* The XML name of the <tt>host</tt> attribute of a <tt>channel</tt> of
* a <tt>content</tt> of a <tt>conference</tt> IQ which represents the
* value of the <tt>host</tt> property of
- * <tt>CobriConferenceIQ.Channel</tt>.
+ * <tt>ColibriConferenceIQ.Channel</tt>.
*/
public static final String HOST_ATTR_NAME = "host";
@@ -253,7 +255,7 @@ public class CobriConferenceIQ
* The XML name of the <tt>id</tt> attribute of a <tt>channel</tt> of a
* <tt>content</tt> of a <tt>conference</tt> IQ which represents the
* value of the <tt>id</tt> property of
- * <tt>CobriConferenceIQ.Channel</tt>.
+ * <tt>ColibriConferenceIQ.Channel</tt>.
*/
public static final String ID_ATTR_NAME = "id";
@@ -261,7 +263,7 @@ public class CobriConferenceIQ
* The XML name of the <tt>rtcpport</tt> attribute of a <tt>channel</tt>
* of a <tt>content</tt> of a <tt>conference</tt> IQ which represents
* the value of the <tt>rtcpPort</tt> property of
- * <tt>CobriConferenceIQ.Channel</tt>.
+ * <tt>ColibriConferenceIQ.Channel</tt>.
*/
public static final String RTCP_PORT_ATTR_NAME = "rtcpport";
@@ -269,7 +271,7 @@ public class CobriConferenceIQ
* The XML name of the <tt>rtpport</tt> attribute of a <tt>channel</tt>
* of a <tt>content</tt> of a <tt>conference</tt> IQ which represents
* the value of the <tt>rtpPort</tt> property of
- * <tt>CobriConferenceIQ.Channel</tt>.
+ * <tt>ColibriConferenceIQ.Channel</tt>.
*/
public static final String RTP_PORT_ATTR_NAME = "rtpport";
@@ -698,7 +700,7 @@ public class CobriConferenceIQ
/**
* The XML name of the <tt>name</tt> attribute of a <tt>content</tt> of
* a <tt>conference</tt> IQ which represents the <tt>name</tt> property
- * of <tt>CobriConferenceIQ.Content</tt>.
+ * of <tt>ColibriConferenceIQ.Content</tt>.
*/
public static final String NAME_ATTR_NAME = "name";
@@ -230,13 +232,13 @@ public class CobriConferenceIQ
/**
* The value of the <tt>expire</tt> property of
- * <tt>CobriConferenceIQ.Channel</tt> which indicates that no actual
+ * <tt>ColibriConferenceIQ.Channel</tt> which indicates that no actual
* value has been specified for the property in question.
*/
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/extensions/cobri/CobriIQProvider.java b/src/net/java/sip/communicator/impl/protocol/jabber/extensions/colibri/ColibriIQProvider.java
index 54d4ccf..10f3d55 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/extensions/cobri/CobriIQProvider.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/extensions/colibri/ColibriIQProvider.java
@@ -4,7 +4,7 @@
* Distributable under LGPL license.
* See terms of license at gnu.org.
*/
-package net.java.sip.communicator.impl.protocol.jabber.extensions.cobri;
+package net.java.sip.communicator.impl.protocol.jabber.extensions.colibri;
import net.java.sip.communicator.impl.protocol.jabber.extensions.jingle.*;
@@ -14,11 +14,11 @@ import org.xmlpull.v1.*;
/**
* Implements an <tt>org.jivesoftware.smack.provider.IQProvider</tt> for the
* Jitsi VideoBridge extension <tt>CobriConferenceIQ</tt>.
*
* @author Lyubomir Marinov
*/
-public class CobriIQProvider
+public class ColibriIQProvider
implements IQProvider
{
/**
@@ -37,19 +37,19 @@ public class CobriIQProvider
String namespace = parser.getNamespace();
IQ iq;
- if (CobriConferenceIQ.ELEMENT_NAME.equals(parser.getName())
- && CobriConferenceIQ.NAMESPACE.equals(namespace))
+ if (ColibriConferenceIQ.ELEMENT_NAME.equals(parser.getName())
+ && ColibriConferenceIQ.NAMESPACE.equals(namespace))
{
- CobriConferenceIQ conference = new CobriConferenceIQ();
- String conferenceID
- = parser.getAttributeValue("", CobriConferenceIQ.ID_ATTR_NAME);
+ ColibriConferenceIQ conference = new ColibriConferenceIQ();
+ String conferenceID = parser
+ .getAttributeValue("", ColibriConferenceIQ.ID_ATTR_NAME);
if ((conferenceID != null) && (conferenceID.length() != 0))
conference.setID(conferenceID);
boolean done = false;
- CobriConferenceIQ.Channel channel = null;
- CobriConferenceIQ.Content content = null;
+ ColibriConferenceIQ.Channel channel = null;
+ ColibriConferenceIQ.Content content = null;
PacketExtensionProvider payloadTypePacketExtensionProvider = null;
StringBuilder ssrc = null;
@@ -61,23 +61,23 @@ public class CobriIQProvider
{
String name = parser.getName();
- if (CobriConferenceIQ.ELEMENT_NAME.equals(name))
+ if (ColibriConferenceIQ.ELEMENT_NAME.equals(name))
{
done = true;
}
- else if (CobriConferenceIQ.Channel.ELEMENT_NAME.equals(
+ else if (ColibriConferenceIQ.Channel.ELEMENT_NAME.equals(
name))
{
content.addChannel(channel);
channel = null;
}
- else if (CobriConferenceIQ.Channel.SSRC_ELEMENT_NAME
+ else if (ColibriConferenceIQ.Channel.SSRC_ELEMENT_NAME
.equals(name))
{
channel.addSSRC(Long.parseLong(ssrc.toString().trim()));
ssrc = null;
}
- else if (CobriConferenceIQ.Content.ELEMENT_NAME.equals(
+ else if (ColibriConferenceIQ.Content.ELEMENT_NAME.equals(
name))
{
conference.addContent(content);
@@ -90,14 +90,14 @@ public class CobriIQProvider
{
String name = parser.getName();
- if (CobriConferenceIQ.Channel.ELEMENT_NAME.equals(name))
+ if (ColibriConferenceIQ.Channel.ELEMENT_NAME.equals(name))
{
- channel = new CobriConferenceIQ.Channel();
+ channel = new ColibriConferenceIQ.Channel();
String channelID
= parser.getAttributeValue(
"",
- CobriConferenceIQ.Channel.ID_ATTR_NAME);
+ ColibriConferenceIQ.Channel.ID_ATTR_NAME);
if ((channelID != null) && (channelID.length() != 0))
channel.setID(channelID);
@@ -105,7 +105,7 @@ public class CobriIQProvider
String host
= parser.getAttributeValue(
"",
- CobriConferenceIQ.Channel.HOST_ATTR_NAME);
+ ColibriConferenceIQ.Channel.HOST_ATTR_NAME);
if ((host != null) && (host.length() != 0))
channel.setHost(host);
@@ -113,7 +113,7 @@ public class CobriIQProvider
String rtpPort
= parser.getAttributeValue(
"",
- CobriConferenceIQ.Channel
+ ColibriConferenceIQ.Channel
.RTP_PORT_ATTR_NAME);
if ((rtpPort != null) && (rtpPort.length() != 0))
@@ -122,7 +122,7 @@ public class CobriIQProvider
String rtcpPort
= parser.getAttributeValue(
"",
- CobriConferenceIQ.Channel
+ ColibriConferenceIQ.Channel
.RTCP_PORT_ATTR_NAME);
if ((rtcpPort != null) && (rtcpPort.length() != 0))
@@ -131,25 +131,25 @@ public class CobriIQProvider
String expire
= parser.getAttributeValue(
"",
- CobriConferenceIQ.Channel.EXPIRE_ATTR_NAME);
+ ColibriConferenceIQ.Channel.EXPIRE_ATTR_NAME);
if ((expire != null) && (expire.length() != 0))
channel.setExpire(Integer.parseInt(expire));
}
- else if (CobriConferenceIQ.Channel.SSRC_ELEMENT_NAME
+ else if (ColibriConferenceIQ.Channel.SSRC_ELEMENT_NAME
.equals(name))
{
ssrc = new StringBuilder();
}
- else if (CobriConferenceIQ.Content.ELEMENT_NAME.equals(
+ else if (ColibriConferenceIQ.Content.ELEMENT_NAME.equals(
name))
{
- content = new CobriConferenceIQ.Content();
+ content = new ColibriConferenceIQ.Content();
String contentName
= parser.getAttributeValue(
"",
- CobriConferenceIQ.Content.NAME_ATTR_NAME);
+ ColibriConferenceIQ.Content.NAME_ATTR_NAME);
if ((contentName != null)
&& (contentName.length() != 0))
@@ -14,11 +14,11 @@ import org.xmlpull.v1.*;
/**
* Implements an <tt>org.jivesoftware.smack.provider.IQProvider</tt> for the
- * Jitsi VideoBridge extension <tt>CobriConferenceIQ</tt>.
+ * Jitsi VideoBridge extension <tt>ColibriConferenceIQ</tt>.
*
* @author Lyubomir Marinov
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/extensions/cobri/CobriStreamConnector.java b/src/net/java/sip/communicator/impl/protocol/jabber/extensions/colibri/ColibriStreamConnector.java
index 3181a58..e91360c 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/extensions/cobri/CobriStreamConnector.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/extensions/colibri/ColibriStreamConnector.java
@@ -4,7 +4,7 @@
* Distributable under LGPL license.
* See terms of license at gnu.org.
*/
-package net.java.sip.communicator.impl.protocol.jabber.extensions.cobri;
+package net.java.sip.communicator.impl.protocol.jabber.extensions.colibri;
import org.jitsi.service.neomedia.*;
@@ -15,11 +15,11 @@ import org.jitsi.service.neomedia.*;
*
* @author Lyubomir Marinov
*/
-public class CobriStreamConnector
+public class ColibriStreamConnector
extends StreamConnectorDelegate<StreamConnector>
{
/**
* Initializes a new <tt>CobriStreamConnector</tt> instance which is to
* share a specific <tt>StreamConnector</tt> instance among multiple
* <tt>TransportManager</tt>s for the purposes of the Jitsi VideoBridge.
*
@@ -27,7 +27,7 @@ public class CobriStreamConnector
* by the new instance among multiple <tt>TransportManager</tt>s for the
* purposes of the Jitsi VideoBridge
*/
- public CobriStreamConnector(StreamConnector streamConnector)
+ public ColibriStreamConnector(StreamConnector streamConnector)
{
super(streamConnector);
}
@@ -15,11 +15,11 @@ import org.jitsi.service.neomedia.*;
{
/**
- * Initializes a new <tt>CobriStreamConnector</tt> instance which is to
+ * Initializes a new <tt>ColibriStreamConnector</tt> instance which is to
* share a specific <tt>StreamConnector</tt> instance among multiple
* <tt>TransportManager</tt>s for the purposes of the Jitsi VideoBridge.